#! /bin/sh

# This script is responsible for speaking out a date stamp.
# It should be installed in your voice directory once you got
# it working correctly.
#
# Input:  $1 - filename for which the date information should be spoken out
#         $2 - sample speed
#         $3 - modem type
#         $4 - compression type
#
# Output: rmd voice file on stdout
#
# This implementation uses GNU find, sox and
# the mbrola synthesizer with german extension txt2pho (hadifix).
# mbrola:  http://tcts.fpms.ac.be/synthesis/
# txt2pho: http://www.ikp.uni-bonn.de/~tpo/HADIFIXforMBROLA.html

SPEED=$2
MODEM_TYPE=$3
COMPRESSION=$4

PIPEFILT=/usr/local/bin/pipefilt
PREPROC=/usr/local/bin/preproc
TXT2PHO=/usr/local/bin/txt2pho
TXT2PHOLIB=/usr/local/txt2pho
PREPROCLIB=/usr/local/txt2pho/preproc
MBROLA=/usr/local/bin/mbrola
MBROLADICT=${TXT2PHOLIB}/voices/de2/de2
SOX=/usr/bin/sox
WAVTOPVF=/usr/bin/wavtopvf
PVFTORMD=/usr/bin/pvftormd
PVFSPEED=/usr/bin/pvfspeed


DAY=$((`find $1 -printf '%Td'`))
HOUR=$((`find $1 -printf '%Tk'`))
MIN=$((`find $1 -printf '%TM'`))

MONTH=$((`find $1 -printf '%Tm'`))
MONTHS[1]=Januar
MONTHS[2]=Februar
MONTHS[3]=Mrz
MONTHS[4]=April
MONTHS[5]=Mai
MONTHS[6]=Juni
MONTHS[7]=Juli
MONTHS[8]=August
MONTHS[9]=September
MONTHS[10]=Oktober
MONTHS[11]=November
MONTHS[12]=Dezember

if [ "$DAY" = "1" ]; then
  TAG=Erster
elif [ "$DAY" = "3" ]; then
  TAG=Dritter
else
  TAG="${DAY}ter"
fi
MSG="$TAG ${MONTHS[$MONTH]}, $HOUR Uhr $MIN"

echo "$MSG" \
  | ${PIPEFILT} \
  | ${PREPROC} ${PREPROCLIB}/Rules.lst ${PREPROCLIB}/Hadifix.abk \
  | ${TXT2PHO} -m \
  | ${MBROLA} ${MBROLADICT} - /tmp/speakdate_$$.wav

${WAVTOPVF} /tmp/speakdate_$$.wav \
  | ${PVFSPEED} -s ${SPEED} \
  | ${PVFTORMD} ${MODEM_TYPE} ${COMPRESSION}

rm /tmp/speakdate_$$.wav
